@@ -77,7 +77,7 @@ fn main() {
                         // root directory that we need to clean up so we don't pollute
                         // the build output/working directory
                         let _ = fs::remove_file("fma_mmm_f32_16x6.asm");
-                        let _ = fs::remove_file("fma_mmm_i8_8x8.asm");
+                        let _ = fs::remove_file("fma_mmm_i32_8x8.asm");
                         let _ = fs::remove_file("fma_sigmoid_f32.asm");
                         let _ = fs::remove_file("fma_tanh_f32.asm");
                     }
@@ -137,7 +137,7 @@ fn main() {
         }
         "aarch64" => {
             let files =
-                preprocess_files("arm64/arm64simd", &[("core", vec!["a53", "gen"])], &suffix);
+                preprocess_files("arm64/arm64simd", &[("core", vec!["a53", "a55", "gen"])], &suffix);
             cc::Build::new().files(files).static_flag(true).compile("arm64");
         }
         _ => {}
@@ -153,8 +153,13 @@ fn preprocess_files(
 ) -> Vec<path::PathBuf> {
     let out_dir = path::PathBuf::from(var("OUT_DIR"));
     let mut files = vec![];
-    for f in input.as_ref().read_dir().unwrap() {
-        let f = f.unwrap();
+    let dir_entries = {
+        let mut dir_entries: Vec<fs::DirEntry> =
+            input.as_ref().read_dir().unwrap().map(|f| f.unwrap()).collect();
+        dir_entries.sort_by(|a, b| a.path().cmp(&b.path()));
+        dir_entries
+    };
+    for f in dir_entries {
         if f.path().extension() == Some(ffi::OsStr::new("tmpl")) {
             let tmpl_file = f.path().file_name().unwrap().to_str().unwrap().to_owned();
             let concerned_variants: Vec<&Variant> =
@@ -269,8 +274,8 @@ fn make_extern_kernel_decl_macro(out_dir: &path::Path, suffix: &str) {
     macro_rules! extern_kernel {
         (fn $name: ident($($par_name:ident : $par_type: ty ),*) -> $rv: ty) => {
             paste! {
-                extern "C" { fn [<$name _ _suffix>]($(par_name: $par_type),*) -> $rv; }
-                use [<$name _ _suffix>] as $name;
+                extern "C" { pub fn [<$name _ _suffix>]($(par_name: $par_type),*) -> $rv; }
+                pub use [<$name _ _suffix>] as $name;
             }
         }
     }"#
