@@ -10,9 +10,9 @@ mod intel;
 
 pub fn plug(ops: &mut Ops) {
     if is_x86_feature_detected!("fma") {
-        ops.mmm_f32_impls.push((mmm::fma_mmm_f32_16x6::mmm(), None));
-        ops.mmm_f32_impls.push((mmm::fma_mmm_f32_8x8::mmm(), None));
         ops.mmv_f32 = Box::new(|_, _| mmm::fma_mmm_f32_64x1::mmm());
+        ops.mmm_f32_impls.push(mmm::fma_mmm_f32_16x6::mmm());
+        ops.mmm_f32_impls.push(mmm::fma_mmm_f32_8x8::mmm());
         ops.sigmoid_f32 = Box::new(|| Box::new(ElementWiseImpl::<sigmoid::SigmoidF32, f32>::new()));
         ops.tanh_f32 = Box::new(|| Box::new(ElementWiseImpl::<tanh::TanhF32, f32>::new()));
         log::info!("mmm_f32, sigmoid_f32, tanh_f32: x86_64/fma activated");
@@ -21,5 +21,4 @@ pub fn plug(ops: &mut Ops) {
         ops.qmmm_i32 = Box::new(|_, _, _| mmm::avx2_mmm_i32_8x8::mmm());
         log::info!("mmm_i8_i8 and mmm_i8_i32: x86_64/avx2 activated");
     }
-    ops.set_cost_models(intel::models());
 }
